
## implements
- [Microsoft Foundry](https://github.com/davidkhala/AI/blob/main/py/davidkhala/ai/openai/azure.py)
- [Azure Document Intelligence](https://github.com/davidkhala/azure-utils/blob/main/py/davidkhala/azure/ai/form.py)
- [Mistral Document AI](https://github.com/davidkhala/AI/blob/main/py/davidkhala/ai/mistral/ocr.py)
